@@ -7,4 +7,4 @@ for converting all the examples from the Ecostress spectral library
 to Sentinel-2 Responses and writing them to a CSV file.
 """
 
-from .converter import EcostressToSentinelConverter
+from sentinel_toolkit.converter.converter import EcostressToSentinelConverter
